@@ -1,12 +1,11 @@
 """
-This submodule is designed to capture Trajectory objects from
+This module is designed to capture Trajectory objects from
 a sequence of images. It contains different tools to extract
 the trajectories based on the color or the motion of the object
 being tracked.
 
 All the resources of this module should be imported directly
-from ``yupi.tracking``. However, we ordered the resources
-according the functionality into the following categories.
+from ``yupi.tracking``.
 """
 
 from yupi.tracking.trackers import (
@@ -17,7 +16,6 @@ from yupi.tracking.trackers import (
 )
 from yupi.tracking.algorithms import (
     TrackingAlgorithm,
-    IntensityMatching,
     ColorMatching,
     FrameDifferencing,
     BackgroundSubtraction,
@@ -37,7 +35,6 @@ __all__ = [
     'CameraTracker',
     'TrackingScenario',
     'TrackingAlgorithm',
-    'IntensityMatching',
     'FrameDifferencing',
     'ColorMatching',
     'BackgroundSubtraction',
@@ -47,5 +44,4 @@ __all__ = [
     'Undistorter',
     'ClassicUndistorter',
     'RemapUndistorter',
-    'NoUndistorter'
 ]
