@@ -3,10 +3,10 @@ from typing import Callable
 from pathlib import Path
 import cv2
 import numpy as np
-from yupi.tracking.algorithms import TrackingAlgorithm, resize_frame
-from yupi.affine_estimator import get_affine
+from yupi.tracking.algorithms import TrackingAlgorithm, _resize_frame
+from yupi.transformations._affine_estimator import _get_affine
 from yupi.trajectory import Trajectory
-from yupi.analyzing.transformations import add_dynamic_reference
+from yupi.transformations import add_moving_FoR
 from yupi.tracking.undistorters import Undistorter
 
 
@@ -220,7 +220,7 @@ class ROI():
 
         self.__global_height, self.__global_width = frame.shape[:2]
 
-        frame_ = resize_frame(frame, scale=self.scale)
+        frame_ = _resize_frame(frame, scale=self.scale)
         cv2.imshow(win1_name, frame_)
 
         # Callback handler to manually set the roi
@@ -368,6 +368,7 @@ class ObjectTracker():
         self.history = []
         self.algorithm = algorithm
         self.preprocessing = preprocessing
+        self.mask = None
 
     def _init_roi(self, frame: np.ndarray) -> bool:
         return self.roi._initialize(self.name, frame)
@@ -461,7 +462,7 @@ class CameraTracker():
         for x0, xf, y0, yf in ignored_regions:
             mask[y0:yf, x0:xf] = 0
 
-        p_good, aff_params, err = get_affine(
+        p_good, aff_params, err = _get_affine(
             img1=prev_frame,
             img2=frame,
             region=self.roi._get_bounds(),
@@ -622,15 +623,15 @@ class TrackingScenario():
                         cv2.FONT_HERSHEY_COMPLEX_SMALL, 1.2, (0, 255, 255), 1,
                         cv2.LINE_AA)
 
-        frame = resize_frame(frame, self.preview_scale)
+        frame = _resize_frame(frame, self.preview_scale)
         cv2.imshow('yupi processing window', frame)
         # Return frame
 
-    def _first_iteration(self, start_in_frame):
+    def _first_iteration(self, start_frame):
         # Start processing frams at the given index
-        if start_in_frame:
-            self.first_frame = start_in_frame
-            self.cap.set(cv2.CAP_PROP_POS_FRAMES, start_in_frame)
+        if start_frame:
+            self.first_frame = start_frame
+            self.cap.set(cv2.CAP_PROP_POS_FRAMES, start_frame)
 
         # Capture the first frame to process
         _, prev_frame = self.cap.read()
@@ -748,12 +749,12 @@ class TrackingScenario():
         for otrack in self.object_trackers:
             t = self._tracker2trajectory(otrack, pix_per_m)
             if self.camera_tracker:
-                t = add_dynamic_reference(t, reference)
+                t = add_moving_FoR(t, reference, new_traj_id=t.traj_id)
             t_list.append(t)
         return t_list
 
-    def track(self, video_path: str, start_in_frame: int = 0,
-              end_in_frame: int = None, pix_per_m: int = 1):
+    def track(self, video_path: str, start_frame: int = 0,
+              end_frame: int = None, pix_per_m: int = 1):
         """
         Starts the tracking process.
 
@@ -761,9 +762,9 @@ class TrackingScenario():
         ----------
         video_path : str
             Path of the video used to track the objects.
-        start_in_frame : int, optional
+        start_frame : int, optional
             Initial frame in which starts the processing, by default 0.
-        end_in_frame : int, optional
+        end_frame : int, optional
             Last frame being processed, if nothing is passed all frames
             until the end of the video will be processed, by default
             None.
@@ -782,14 +783,14 @@ class TrackingScenario():
             process.
         """
 
-        if end_in_frame is not None and end_in_frame > start_in_frame:
-            self.last_frame = int(end_in_frame)
+        if end_frame is not None and end_frame > start_frame:
+            self.last_frame = int(end_frame)
 
         self._digest_video_path(video_path)
 
         end = False
         if self._iteration_counter == 0:
-            retval = self._first_iteration(start_in_frame)
+            retval = self._first_iteration(start_frame)
             if not retval:
                 return retval, None
 
